@@ -50,17 +50,18 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk
 import aws_cdk.aws_ec2
 import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.aws_rds
 import aws_cdk.aws_secretsmanager
-import aws_cdk.core
+import constructs
 
 
 @jsii.implements(aws_cdk.aws_rds.IServerlessCluster)
 class ServerlessClusterFromSnapshot(
-    aws_cdk.core.Resource,
+    aws_cdk.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/cdk-serverless-cluster-from-snapshot.ServerlessClusterFromSnapshot",
 ):
@@ -71,20 +72,20 @@ class ServerlessClusterFromSnapshot(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         engine: aws_cdk.aws_rds.IClusterEngine,
         snapshot_identifier: builtins.str,
         vpc: aws_cdk.aws_ec2.IVpc,
-        backup_retention: typing.Optional[aws_cdk.core.Duration] = None,
+        backup_retention: typing.Optional[aws_cdk.Duration] = None,
         cluster_identifier: typing.Optional[builtins.str] = None,
         credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
         default_database_name: typing.Optional[builtins.str] = None,
         deletion_protection: typing.Optional[builtins.bool] = None,
         enable_data_api: typing.Optional[builtins.bool] = None,
         parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         scaling: typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions] = None,
         security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
@@ -138,7 +139,7 @@ class ServerlessClusterFromSnapshot(
         id: builtins.str,
         *,
         secret: aws_cdk.aws_secretsmanager.ISecret,
-        automatically_after: typing.Optional[aws_cdk.core.Duration] = None,
+        automatically_after: typing.Optional[aws_cdk.Duration] = None,
         endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
         exclude_characters: typing.Optional[builtins.str] = None,
         vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
@@ -166,7 +167,7 @@ class ServerlessClusterFromSnapshot(
     def add_rotation_single_user(
         self,
         *,
-        automatically_after: typing.Optional[aws_cdk.core.Duration] = None,
+        automatically_after: typing.Optional[aws_cdk.Duration] = None,
         endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
         exclude_characters: typing.Optional[builtins.str] = None,
         vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
@@ -280,14 +281,14 @@ class ServerlessClusterFromSnapshotProps:
         engine: aws_cdk.aws_rds.IClusterEngine,
         snapshot_identifier: builtins.str,
         vpc: aws_cdk.aws_ec2.IVpc,
-        backup_retention: typing.Optional[aws_cdk.core.Duration] = None,
+        backup_retention: typing.Optional[aws_cdk.Duration] = None,
         cluster_identifier: typing.Optional[builtins.str] = None,
         credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
         default_database_name: typing.Optional[builtins.str] = None,
         deletion_protection: typing.Optional[builtins.bool] = None,
         enable_data_api: typing.Optional[builtins.bool] = None,
         parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
         scaling: typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions] = None,
         security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
@@ -376,7 +377,7 @@ class ServerlessClusterFromSnapshotProps:
         return typing.cast(aws_cdk.aws_ec2.IVpc, result)
 
     @builtins.property
-    def backup_retention(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def backup_retention(self) -> typing.Optional[aws_cdk.Duration]:
         '''The number of days during which automatic DB snapshots are retained.
 
         Automatic backup retention cannot be disabled on serverless clusters.
@@ -385,7 +386,7 @@ class ServerlessClusterFromSnapshotProps:
         :default: Duration.days(1)
         '''
         result = self._values.get("backup_retention")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[aws_cdk.Duration], result)
 
     @builtins.property
     def cluster_identifier(self) -> typing.Optional[builtins.str]:
@@ -444,13 +445,13 @@ class ServerlessClusterFromSnapshotProps:
         return typing.cast(typing.Optional[aws_cdk.aws_rds.IParameterGroup], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
         '''The removal policy to apply when the cluster and its instances are removed from the stack or replaced during an update.
 
         :default: - RemovalPolicy.SNAPSHOT (remove the cluster and instances, but retain a snapshot of the data)
         '''
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
 
     @builtins.property
     def scaling(self) -> typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions]:
